@@ -88,11 +88,18 @@ change_to_unix_dir_separator (char *path)
 	char *c;
 	
 	for (c = path; *c != 0; c++)
-		if (*c == '\\')
+		if ((*c == '\\') && (*(c+1) != '\\'))
 			*c = '/';
 }
 
 
+static char*
+to_dos (const char *path)
+{
+	return str_substitute (path, "/", "\\\\");
+}
+
+
 static int
 str_rfind (const char *str, 
 	   int         c)
@@ -131,6 +138,12 @@ list__process_line (char     *line,
 
 	fields = split_line (line, 4);
 
+	if (g_strv_length (fields) < 4) {
+		g_strfreev (fields);
+		file_data_free (fdata);
+		return;
+	}
+
 	if (fields[2][0] == 'D') { /* skip directories */
 		g_strfreev (fields);
 		file_data_free (fdata);
@@ -158,7 +171,6 @@ list__process_line (char     *line,
 		
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	comm->file_list = g_list_prepend (comm->file_list, fdata);
 }
@@ -175,7 +187,8 @@ fr_command_7z_begin_command (FRCommand *comm)
 
 
 static void
-fr_command_7z_list (FRCommand *comm)
+fr_command_7z_list (FRCommand  *comm,
+		    const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      list__process_line,
@@ -228,7 +241,7 @@ fr_command_7z_add (FRCommand     *comm,
 	fr_process_add_arg (comm->process, comm->e_filename);
 
 	for (scan = file_list; scan; scan = scan->next) {
-		char *filename = str_substitute ((char*) scan->data, "/", "\\\\");
+		char *filename = to_dos (scan->data);
 		fr_process_add_arg (comm->process, filename);
 		g_free (filename);
 	}
@@ -251,7 +264,7 @@ fr_command_7z_delete (FRCommand *comm,
 	fr_process_add_arg (comm->process, comm->e_filename);
 
 	for (scan = file_list; scan; scan = scan->next) {
-		char *filename = str_substitute ((char*) scan->data, "/", "\\\\");
+		char *filename = to_dos (scan->data);
 		fr_process_add_arg (comm->process, filename);
 		g_free (filename);
 	}
@@ -292,7 +305,7 @@ fr_command_7z_extract (FRCommand  *comm,
 	fr_process_add_arg (comm->process, comm->e_filename);
 
 	for (scan = file_list; scan; scan = scan->next) {
-		char *filename = str_substitute ((char*) scan->data, "/", "\\\\");
+		char *filename = to_dos (scan->data);
 		fr_process_add_arg (comm->process, filename);
 		g_free (filename);
 	}
