@@ -180,7 +180,6 @@ process_line (char     *line,
 
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -190,7 +189,8 @@ process_line (char     *line,
 
 
 static void
-fr_command_ar_list (FRCommand *comm)
+fr_command_ar_list (FRCommand  *comm,
+		    const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      process_line,
